@@ -44,7 +44,7 @@ namespace {
 }
 
 FunctionEdit::FunctionEdit(QWidget *parent)
-    : QWidget(parent), m_calcUplimit(0), m_calcDownlimit(0)
+    : QWidget(parent), m_calcUplimit(0), m_calcDownlimit(0), m_modmode(false)
 {
     setWindowTitle(i18n("Add/Edit a function"));
     
@@ -163,7 +163,7 @@ void FunctionEdit::colorChange(int)
     setColor(m_color->color());
 }
 
-static double calcExp(const Analitza::Expression& exp, Analitza::Variables* v, bool* corr)
+static double calcExp(const Analitza::Expression& exp, const QSharedPointer<Analitza::Variables>& v, bool* corr)
 {
     Q_ASSERT(exp.isCorrect());
     Analitza::Analyzer d(v);
